@@ -69,10 +69,8 @@
  *
  * // Register 'method' at '/plugins/example' with one required
  * // string argument 'arg1'
- * GeditMessageType *message_type = gedit_message_bus_register ("/plugins/example", "method",
- *                                                              0,
- *                                                              "arg1", G_TYPE_STRING,
- *                                                              NULL);
+ * gedit_message_bus_register (bus, EXAMPLE_TYPE_METHOD_MESSAGE,
+ *                             "/plugins/example", "method");
  * </programlisting>
  * </example>
  * <example>
@@ -116,8 +114,6 @@
  *
  */
 
-#define GEDIT_MESSAGE_BUS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_MESSAGE_BUS, GeditMessageBusPrivate))
-
 typedef struct
 {
 	gchar *object_path;
@@ -176,7 +172,7 @@ static guint message_bus_signals[LAST_SIGNAL];
 static void gedit_message_bus_dispatch_real (GeditMessageBus *bus,
                                              GeditMessage    *message);
 
-G_DEFINE_TYPE(GeditMessageBus, gedit_message_bus, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GeditMessageBus, gedit_message_bus, G_TYPE_OBJECT)
 
 static MessageIdentifier *
 message_identifier_new (const gchar *object_path,
@@ -298,7 +294,8 @@ gedit_message_bus_class_init (GeditMessageBusClass *klass)
 	/**
 	 * GeditMessageBus::registered:
 	 * @bus: a #GeditMessageBus
-	 * @message_type: the registered #GeditMessageType
+	 * @object_path: the registered object path.
+	 * @method: the registered method
 	 *
 	 * The "registered" signal is emitted when a message has been registered
 	 * on the bus.
@@ -320,7 +317,8 @@ gedit_message_bus_class_init (GeditMessageBusClass *klass)
 	/**
 	 * GeditMessageBus::unregistered:
 	 * @bus: a #GeditMessageBus
-	 * @message_type: the unregistered #GeditMessageType
+	 * @object_path: the unregistered object path.
+	 * @method: the unregistered method
 	 *
 	 * The "unregistered" signal is emitted when a message has been
 	 * unregistered from the bus.
@@ -338,8 +336,6 @@ gedit_message_bus_class_init (GeditMessageBusClass *klass)
 		              2,
 		              G_TYPE_STRING,
 		              G_TYPE_STRING);
-
-	g_type_class_add_private (object_class, sizeof (GeditMessageBusPrivate));
 }
 
 static Message *
@@ -593,7 +589,7 @@ free_type (gpointer data)
 static void
 gedit_message_bus_init (GeditMessageBus *self)
 {
-	self->priv = GEDIT_MESSAGE_BUS_GET_PRIVATE (self);
+	self->priv = gedit_message_bus_get_instance_private (self);
 
 	self->priv->messages = g_hash_table_new_full (message_identifier_hash,
 	                                              message_identifier_equal,
