@@ -70,11 +70,6 @@ enum
 	NUM_COLUMNS
 };
 
-
-#define GEDIT_PREFERENCES_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-						     GEDIT_TYPE_PREFERENCES_DIALOG, \
-						     GeditPreferencesDialogPrivate))
-
 struct _GeditPreferencesDialogPrivate
 {
 	GSettings	*editor;
@@ -118,6 +113,7 @@ struct _GeditPreferencesDialogPrivate
 
 	/* Right margin */
 	GtkWidget	*right_margin_checkbutton;
+	GtkWidget       *right_margin_position_grid;
 	GtkWidget	*right_margin_position_spinbutton;
 
 	/* Highlighting */
@@ -128,9 +124,7 @@ struct _GeditPreferencesDialogPrivate
 	GtkWidget	*plugin_manager_place_holder;
 };
 
-
-G_DEFINE_TYPE(GeditPreferencesDialog, gedit_preferences_dialog, GTK_TYPE_DIALOG)
-
+G_DEFINE_TYPE_WITH_PRIVATE (GeditPreferencesDialog, gedit_preferences_dialog, GTK_TYPE_DIALOG)
 
 static void
 gedit_preferences_dialog_dispose (GObject *object)
@@ -176,34 +170,33 @@ gedit_preferences_dialog_class_init (GeditPreferencesDialogClass *klass)
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-preferences-dialog.ui");
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, notebook);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, display_line_numbers_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, right_margin_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, right_margin_position_spinbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, highlight_current_line_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, bracket_matching_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, wrap_text_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, split_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, tabs_width_spinbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, insert_spaces_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, auto_indent_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, backup_copy_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, auto_save_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, auto_save_spinbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, default_font_checkbutton);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, font_button);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, font_grid);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_treeview_model);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_treeview);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_column);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_renderer);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_scrolled_window);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, install_scheme_button);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, uninstall_scheme_button);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, schemes_toolbar);
-	gtk_widget_class_bind_child (widget_class, GeditPreferencesDialogPrivate, plugin_manager_place_holder);
-
-	g_type_class_add_private (object_class, sizeof (GeditPreferencesDialogPrivate));
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, notebook);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, display_line_numbers_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, right_margin_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, right_margin_position_grid);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, right_margin_position_spinbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, highlight_current_line_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, bracket_matching_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, wrap_text_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, split_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, tabs_width_spinbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, insert_spaces_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, auto_indent_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, backup_copy_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, auto_save_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, auto_save_spinbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, default_font_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, font_button);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, font_grid);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_treeview_model);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_treeview);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_column);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_renderer);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_scrolled_window);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, install_scheme_button);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, uninstall_scheme_button);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, schemes_toolbar);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPreferencesDialog, plugin_manager_place_holder);
 }
 
 static void
@@ -299,23 +292,6 @@ wrap_mode_checkbutton_toggled (GtkToggleButton        *button,
 			     mode);
 }
 
-static void
-right_margin_checkbutton_toggled (GtkToggleButton        *button,
-				  GeditPreferencesDialog *dlg)
-{
-	gboolean active;
-
-	g_return_if_fail (button == GTK_TOGGLE_BUTTON (dlg->priv->right_margin_checkbutton));
-
-	active = gtk_toggle_button_get_active (button);
-
-	g_settings_set_boolean (dlg->priv->editor, GEDIT_SETTINGS_DISPLAY_RIGHT_MARGIN,
-				active);
-
-	gtk_widget_set_sensitive (dlg->priv->right_margin_position_spinbutton,
-				  active);
-}
-
 static void
 setup_view_page (GeditPreferencesDialog *dlg)
 {
@@ -366,8 +342,6 @@ setup_view_page (GeditPreferencesDialog *dlg)
 	/* Set widgets sensitivity */
 	gtk_widget_set_sensitive (dlg->priv->split_checkbutton,
 				  (wrap_mode != GTK_WRAP_NONE));
-	gtk_widget_set_sensitive (dlg->priv->right_margin_position_spinbutton,
-				  display_right_margin);
 	/* Connect signals */
 	g_settings_bind (dlg->priv->editor,
 			 GEDIT_SETTINGS_DISPLAY_LINE_NUMBERS,
@@ -379,6 +353,16 @@ setup_view_page (GeditPreferencesDialog *dlg)
 			 dlg->priv->highlight_current_line_checkbutton,
 			 "active",
 			 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+	g_settings_bind (dlg->priv->editor,
+	                 GEDIT_SETTINGS_DISPLAY_RIGHT_MARGIN,
+	                 dlg->priv->right_margin_checkbutton,
+	                 "active",
+	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+	g_settings_bind (dlg->priv->editor,
+	                 GEDIT_SETTINGS_DISPLAY_RIGHT_MARGIN,
+	                 dlg->priv->right_margin_position_grid,
+	                 "sensitive",
+	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 	g_settings_bind (dlg->priv->editor,
 			 GEDIT_SETTINGS_RIGHT_MARGIN_POSITION,
 			 dlg->priv->right_margin_position_spinbutton,
@@ -397,31 +381,12 @@ setup_view_page (GeditPreferencesDialog *dlg)
 			  "toggled",
 			  G_CALLBACK (wrap_mode_checkbutton_toggled),
 			  dlg);
-	g_signal_connect (dlg->priv->right_margin_checkbutton,
-			  "toggled",
-			  G_CALLBACK (right_margin_checkbutton_toggled),
-			  dlg);
-}
-
-static void
-on_use_default_font_changed (GSettings              *settings,
-			     const gchar            *key,
-			     GeditPreferencesDialog *dlg)
-{
-	gboolean value;
-
-	gedit_debug (DEBUG_PREFS);
-
-	value = g_settings_get_boolean (settings, key);
-
-	gtk_widget_set_sensitive (dlg->priv->font_grid, !value);
 }
 
 static void
 setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 {
 	GObject *settings;
-	gboolean use_default_font;
 	gchar *system_font = NULL;
 	gchar *label;
 
@@ -440,8 +405,6 @@ setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 	/* Get values */
 	settings = _gedit_app_get_settings (GEDIT_APP (g_application_get_default ()));
 	system_font = gedit_settings_get_system_font (GEDIT_SETTINGS (settings));
-	use_default_font = g_settings_get_boolean (dlg->priv->editor,
-						   GEDIT_SETTINGS_USE_DEFAULT_FONT);
 
 	label = g_strdup_printf(_("_Use the system fixed width font (%s)"),
 				system_font);
@@ -450,23 +413,17 @@ setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 	g_free (system_font);
 	g_free (label);
 
-	/* read current config and setup initial state */
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->default_font_checkbutton),
-				      use_default_font);
-
-	/* Set initial widget sensitivity */
-	gtk_widget_set_sensitive (dlg->priv->font_grid, !use_default_font);
-
-	/* Connect signals */
-	g_signal_connect (dlg->priv->editor,
-			  "changed::use-default-font",
-			  G_CALLBACK (on_use_default_font_changed),
-			  dlg);
+	/* Bind settings */
 	g_settings_bind (dlg->priv->editor,
 			 GEDIT_SETTINGS_USE_DEFAULT_FONT,
 			 dlg->priv->default_font_checkbutton,
 			 "active",
 			 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+	g_settings_bind (dlg->priv->editor,
+			 GEDIT_SETTINGS_USE_DEFAULT_FONT,
+			 dlg->priv->font_grid,
+			 "sensitive",
+			 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET | G_SETTINGS_BIND_INVERT_BOOLEAN);
 	g_settings_bind (dlg->priv->editor,
 			 GEDIT_SETTINGS_EDITOR_FONT,
 			 dlg->priv->font_button,
@@ -1139,7 +1096,7 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 {
 	gedit_debug (DEBUG_PREFS);
 
-	dlg->priv = GEDIT_PREFERENCES_DIALOG_GET_PRIVATE (dlg);
+	dlg->priv = gedit_preferences_dialog_get_instance_private (dlg);
 	dlg->priv->editor = g_settings_new ("org.gnome.gedit.preferences.editor");
 
 	gtk_widget_init_template (GTK_WIDGET (dlg));
